@@ -3,23 +3,27 @@
 from pages.widgets_registry import get_widget
 from pages import settings
 from pages.models import Content
-from pages.widgets import ImageInput, VideoWidget
+from pages.widgets import ImageInput, VideoWidget, FileInput
 
+from django import forms
+from django.core.mail import send_mail
 from django import template
 from django.template import TemplateSyntaxError
 from django.core.files.storage import default_storage
-from django.forms import Textarea, ImageField, CharField
+from django.forms import Textarea, ImageField, CharField, FileField
 from django.forms import TextInput
 from django.conf import settings as global_settings
 from django.utils.translation import ugettext_lazy as _
 from django.utils.safestring import mark_safe
 from django.template.loader import render_to_string
 
+import logging
 import os
 import time
 import re
 
 PLACEHOLDER_ERROR = _("[Placeholder %(name)s had syntax error: %(error)s]")
+logger = logging.getLogger(__name__)
 
 
 def parse_placeholder(parser, token):
@@ -89,7 +93,7 @@ class PlaceholderNode(template.Node):
     widget = TextInput
 
     def __init__(self, name, page=None, widget=None, parsed=False,
-            as_varname=None, inherited=False, untranslated=False):
+            as_varname=None, inherited=False, untranslated=False, has_revision=True):
         """Gather parameters for the `PlaceholderNode`.
 
         These values should be thread safe and don't change between calls."""
@@ -101,6 +105,7 @@ class PlaceholderNode(template.Node):
         self.inherited = inherited
         self.untranslated = untranslated
         self.as_varname = as_varname
+
         self.found_in_block = None
 
     def get_widget(self, page, language, fallback=Textarea):
@@ -203,10 +208,12 @@ class PlaceholderNode(template.Node):
             lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
         return self.get_content(context[self.page], lang, lang_fallback)
 
+    def get_render_content(self, context):
+        return mark_safe(self.get_content_from_context(context))
+
     def render(self, context):
         """Output the content of the `PlaceholdeNode` in the template."""
-
-        content = mark_safe(self.get_content_from_context(context))
+        content = self.get_render_content(context)
         if not content:
             return ''
         if self.parsed:
@@ -277,6 +284,87 @@ class ImagePlaceholderNode(PlaceholderNode):
                 change
             )
 
+class FilePlaceholderNode(PlaceholderNode):
+    """A `PlaceholderNode` that saves one file on disk.
+
+    `PAGE_UPLOAD_ROOT` setting define where to save the file.
+    """
+
+    def get_field(self, page, language, initial=None):
+        help_text = ""
+        widget = FileInput(page, language)
+        return FileField(
+            widget=widget,
+            initial=initial,
+            help_text=help_text,
+            required=False
+        )
+
+    def save(self, page, language, data, change, extra_data=None):
+        if 'delete' in extra_data:
+            return super(FilePlaceholderNode, self).save(
+                page,
+                language,
+                "",
+                change
+            )
+        filename = ''
+        if change and data:
+            # the image URL is posted if not changed
+            if type(data) is unicode:
+                return
+            filename = os.path.join(
+                settings.PAGE_UPLOAD_ROOT,
+                'page_' + str(page.id),
+                self.name + '-' + str(time.time())
+            )
+
+            m = re.search('\.[a-zA-Z]{1,4}$', str(data))
+            if m is not None:
+                filename += m.group(0).lower()
+
+            filename = default_storage.save(filename, data)
+            return super(FilePlaceholderNode, self).save(
+                page,
+                language,
+                filename,
+                change
+            )
+
+
+class ContactForm(forms.Form):
+  
+    email = forms.EmailField(label=_('Your email'))
+    subject = forms.CharField(label=_('Subject'), 
+      max_length=150)
+    message = forms.CharField(widget=forms.Textarea(),
+      label=_('Your message'))
+    
+
+class ContactPlaceholderNode(PlaceholderNode):
+    """A contact `PlaceholderNode` example."""
+
+    def render(self, context):
+        content = self.get_content_from_context(context)
+        request = context.get('request', None)
+        if not request:
+            raise ValueError('request no available in the context.')
+        if request.method == 'POST':
+            form = ContactForm(request.POST)
+            if form.is_valid():
+                data = form.cleaned_data
+                recipients = [adm[1] for adm in global_settings.ADMINS]
+                try:
+                    send_mail(data['subject'], data['message'], 
+                        data['email'], recipients, fail_silently=False)
+                    return _("Your email has been sent. Thank you.")
+                except:
+                    return _("An error as occured: your email has not been sent.")
+        else:
+            form = ContactForm()
+        renderer = render_to_string('pages/contact.html', {'form':form})
+        return mark_safe(renderer)
+
 
 class VideoPlaceholderNode(PlaceholderNode):
     """A youtube `PlaceholderNode`, just here as an example."""
@@ -300,3 +388,15 @@ class VideoPlaceholderNode(PlaceholderNode):
             renderer = render_to_string('pages/embed.html', context)
             return mark_safe(renderer)
         return ''
+
+
+class JsonPlaceholderNode(PlaceholderNode):
+
+    def get_render_content(self, context):
+        import json
+        content = self.get_content_from_context(context)
+        try:
+            return json.loads(str(content))
+        except:
+            logger.error("Problem decoding json")
+        return content
